@@ -143,7 +143,6 @@ class PythonCodeGen(CodeGenBase):
         idfield: str,
         optional_fields: set[str],
     ) -> None:
-        class_uri = classname
         classname = self.safe_name(classname)
 
         if extends:
@@ -164,7 +163,9 @@ class PythonCodeGen(CodeGenBase):
             self.out.write("    pass\n\n\n")
             return
 
-        self.out.write(f'    class_uri = "{class_uri}"\n\n')
+        idfield_safe_name = self.safe_name(idfield) if idfield != "" else None
+        if idfield_safe_name is not None:
+            self.out.write(f"    {idfield_safe_name}: str\n\n")
 
         required_field_names = [f for f in field_names if f not in optional_fields]
         optional_field_names = [f for f in field_names if f in optional_fields]
@@ -203,6 +204,11 @@ class PythonCodeGen(CodeGenBase):
 """.format(
                     classname
                 )
+            elif name == idfield_safe_name:
+                field_inits += """        self.{0} = {0} if {0} is not None else "_:" + str(_uuid__.uuid4())
+""".format(
+                    self.safe_name(name)
+                )
             else:
                 field_inits += """        self.{0} = {0}
 """.format(
@@ -590,7 +596,8 @@ if _errors__:
 
         if shortname(name) == "class":
             self.out.write(
-                """{spc}            if {safename} != cls.__name__ and {safename} != cls.class_uri:
+                """
+{spc}            if {safename} not in (cls.__name__, loadingOptions.vocab.get(cls.__name__)):
 {spc}               raise ValidationException(f"tried `{{cls.__name__}}` but")
 {spc}        except ValidationException as e:
 {spc}               raise e
@@ -650,7 +657,29 @@ if _errors__:
         else:
             baseurl = f"self.{self.safe_name(self.idfield)}"
 
-        if fieldtype.is_uri:
+        if shortname(name) == "class":
+            self.serializer.write(
+                fmt(
+                    """
+if self.{safename} is not None:
+    uri = self.loadingOptions.vocab[self.{safename}]
+    if p := self.loadingOptions.rvocab.get(uri[:-len(self.{safename})]):
+        uri = f"{{p}}:{{self.{safename}}}"
+    else:
+        uri = self.{safename}
+    u = save_relative_uri(uri, {baseurl}, {scoped_id}, {ref_scope}, relative_uris)
+    r["{fieldname}"] = u
+""".format(
+                        safename=self.safe_name(name),
+                        fieldname=shortname(name).strip(),
+                        baseurl=baseurl,
+                        scoped_id=fieldtype.scoped_id,
+                        ref_scope=fieldtype.ref_scope,
+                    ),
+                    8,
+                )
+            )
+        elif fieldtype.is_uri:
             self.serializer.write(
                 fmt(
                     """
